diff --git a/web/pgadmin/misc/cloud/__init__.py b/web/pgadmin/misc/cloud/__init__.py
index eff20bad9..67a468b30 100644
--- a/web/pgadmin/misc/cloud/__init__.py
+++ b/web/pgadmin/misc/cloud/__init__.py
@@ -27,6 +27,7 @@ from pgadmin.misc.cloud.biganimal import deploy_on_biganimal,\
     clear_biganimal_session
 from pgadmin.misc.cloud.rds import deploy_on_rds, clear_aws_session
 from pgadmin.misc.cloud.azure import deploy_on_azure, clear_azure_session
+import config
 
 # set template path for sql scripts
 MODULE_NAME = 'cloud'
@@ -135,7 +136,11 @@ def deploy_on_cloud():
     elif data['cloud'] == 'biganimal':
         status, resp = deploy_on_biganimal(data)
     elif data['cloud'] == 'azure':
-        status, resp = deploy_on_azure(data)
+        if config.SERVER_MODE:
+            status = False
+            resp = gettext('Invalid Operation for Server mode.')
+        else:
+            status, resp = deploy_on_azure(data)
     else:
         status = False
         resp = gettext('No cloud implementation.')
diff --git a/web/pgadmin/misc/cloud/static/js/CloudWizard.jsx b/web/pgadmin/misc/cloud/static/js/CloudWizard.jsx
index 0a03be100..c56f94534 100644
--- a/web/pgadmin/misc/cloud/static/js/CloudWizard.jsx
+++ b/web/pgadmin/misc/cloud/static/js/CloudWizard.jsx
@@ -325,6 +325,11 @@ export default function CloudWizard({ nodeInfo, nodeData }) {
     setErrMsg([]);
   });
 
+  let cloud_providers = [{label: 'Amazon RDS', value: 'rds', icon: <AWSIcon className={classes.icon} />}, {label: 'EDB BigAnimal', value: 'biganimal', icon: <BigAnimalIcon className={classes.icon} />}];
+  if (pgAdmin.server_mode == 'False'){
+    cloud_providers.push({'label': 'Azure PostgreSQL', value: 'azure', icon: <AzureIcon className={classes.icon} /> });
+  }
+
   return (
     <CloudWizardEventsContext.Provider value={eventBus.current}>
       <>
@@ -342,7 +347,7 @@ export default function CloudWizard({ nodeInfo, nodeData }) {
             </Box>
             <Box className={classes.messageBox}>
               <ToggleButtons cloudProvider={cloudProvider} setCloudProvider={setCloudProvider}
-                options={[{label: 'Amazon RDS', value: 'rds', icon: <AWSIcon className={classes.icon} />}, {label: 'EDB BigAnimal', value: 'biganimal', icon: <BigAnimalIcon className={classes.icon} />}, {'label': 'Azure PostgreSQL', value: 'azure', icon: <AzureIcon className={classes.icon} /> }]}
+                options={cloud_providers}
               ></ToggleButtons>
             </Box>
             <FormFooterMessage type={errMsg[0]} message={errMsg[1]} onClose={onErrClose} />
